@@ -6,9 +6,18 @@ class User2(StructuredNode):
 
 
 def test_cypher():
+    """
+    py2neo's cypher result format changed in 1.6 this tests its return value
+    is backward compatible with earlier versions of neomodel
+    """
+
     jim = User2(email='jim1@test.com').save()
-    email = jim.cypher("START a=node({self}) RETURN a.email")[0][0][0]
-    assert email == 'jim1@test.com'
+    data, meta = jim.cypher("START a=node({self}) RETURN a.email")
+    assert data[0][0] == 'jim1@test.com'
+    assert 'a.email' in meta
+
+    data, meta = jim.cypher("START a=node({self}) MATCH (a)<-[:USER2]-(b) RETURN a, b, 3")
+    assert 'a' in meta and 'b' in meta
 
 
 def test_cypher_syntax_error():
